get_forecast_for(latitude, longitude, timestamp, units = "us", language = "en", exclude = NULL)[YYYY]-[MM]-[DD]T[HH]:[MM]:[SS] (with an optional
time zone formatted as Z for GMT time or [+|-][HH][MM] for an offset in hours
or minutes). For the latter format, if no timezone is present, local time (at the provided
latitude and longitude) is assumed. (This string format is a subset of ISO 8601 time. An
as example, 2013-05-06T12:00:00-0400.)currently, minutely,
hourly, daily, alerts, flags). Crafting a request with all of
the above blocks excluded is exceedingly silly and not recommended. Setting this parameter
to NULL (the default) does not exclude any parameters from the results.rforecastio object that contains the original JSON response object, a list
of named `tbl_df` `data.frame` objects corresponding to what was returned by the API and
relevant response headers (cache-control, expires, x-forecast-api-calls,
x-response-time).
units to
one of (si, ca, uk). Setting units to auto will
have the API select the relevant units automatically, based on geographic location. This
value is set to us (Imperial) units by default.If you wish to have text summaries presented in a different language, set language to
one of (ar, bs, de, es, fr, it, nl, pl,
pt, ru, sv, tet, tr, x-pig-latin, zh). This value
is set to en (English) by default.
See the Options section of the official Forecast API documentation for more information.
tmp <- get_current_forecast_for(37.8267,-122.423, "2013-05-06T12:00:00-0400")
Run the code above in your browser using DataLab